# Spherical Channels for Modeling Atomic Interactions

C. Lawrence Zitnick, Abhishek Das, Adeesh Kolluru, Janice Lan, Muhammed Shuaibi, Anuroop Sriram, Zachary Ulissi, Brandon Wood

[[`arXiv:2206.14331`](https://arxiv.org/abs/2206.14331)]

To run the Spherical Channel Network (SCN), install [e3nn](https://github.com/e3nn/e3nn/) with `pip install e3nn==0.2.6`.

SCN was developed with e3nn v0.2.6, and might run slower with later versions [[1](https://github.com/FAIR-Chem/fairchem/issues/397), [2](https://github.com/FAIR-Chem/fairchem/pull/402)].

## Citing

If you use SCN in your work, please consider citing:

```bibtex
@inproceedings{zitnick_scn_2022,
  title = {{Spherical Channels for Modeling Atomic Interactions}},
  author = {Zitnick, C. Lawrence and Das, Abhishek and Kolluru, Adeesh and Lan, Janice and Shuaibi, Muhammed and Sriram, Anuroop and Ulissi, Zachary and Wood, Brandon},
  booktitle = {Advances in Neural Information Processing Systems (NeurIPS)},
  year = {2022},
}
```
